#ifndef IMAP_QUOTA_PLUGIN_H
#define IMAP_QUOTA_PLUGIN_H

void imap_quota_plugin_init(void);
void imap_quota_plugin_deinit(void);

#endif
